@@ -1,9 +1,17 @@
 #!/usr/bin/env python
 # coding=utf8
 
-from wtforms.fields import HiddenField
 from flask import Blueprint
 
+try:
+    from wtforms.fields import HiddenField
+except ImportError:
+    def is_hidden_field_filter(field):
+        raise RuntimeError('WTForms is not installed.')
+else:
+    def is_hidden_field_filter(field):
+        return isinstance(field, HiddenField)
+
 
 class Bootstrap(object):
     def __init__(self, app=None):
@@ -28,7 +36,3 @@ class Bootstrap(object):
 
         app.jinja_env.filters['bootstrap_is_hidden_field'] =\
             is_hidden_field_filter
-
-
-def is_hidden_field_filter(field):
-    return isinstance(field, HiddenField)
